/*
 *  Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 * 
 *    https://www.apache.org/licenses/LICENSE-2.0
 * 
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 * 
 */
package org.apache.directory.api.ldap.model.name;


import static org.junit.jupiter.api.Assertions.assertEquals;
import org.apache.directory.api.ldap.model.exception.LdapInvalidDnException;
import org.apache.directory.api.ldap.model.schema.SchemaManager;
import org.junit.jupiter.api.Test;
import org.junit.jupiter.api.parallel.Execution;
import org.junit.jupiter.api.parallel.ExecutionMode;


/**
 * Test the class Dn
 *
 * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>
 */
@Execution(ExecutionMode.CONCURRENT)
public class DnTest
{
    /** A null schemaManager used in tests */
    SchemaManager schemaManager = null;


    @Test
    public void testAddRdn() throws LdapInvalidDnException
    {
        Dn dn = new Dn( "B=b,A=a" );
        Rdn rdn = new Rdn( "C=c" );
        
        dn = dn.add( rdn );
        
        assertEquals( "C=c,B=b,A=a", dn.getName() );
        assertEquals( "c=c,b=b,a=a", dn.getNormName() );
    }
    
    @Test
    public void ancestorCheck() throws LdapInvalidDnException
    {
        Dn group = new Dn( "ou=group,ou=base" );
        Dn base = new Dn( "ou=base" );

        Dn ancestor = group.getAncestorOf( "ou=group" );
        assertEquals( ancestor, base );
    }
}
